
//=====================================================================================================================
/// @file		RFM95W.h
///
/// @brief		Variables and Functions for RFM95W
///
/// @version	V1.0
///
/// @date		01.08.2020
///
/// @author		Philipp Holle
//=====================================================================================================================
#ifndef RFM95W_H_
#define RFM95W_H_
//---------------------------------------------------------------------------------------------------------------------
// Includes
//---------------------------------------------------------------------------------------------------------------------
#include <avr/io.h>
#include <stdbool.h>
#include "ph_auxiliaries.h"
#include "lorawan.h"
#include "SPI_ATmega328p.h"
//---------------------------------------------------------------------------------------------------------------------
// Defines
//---------------------------------------------------------------------------------------------------------------------
#define PRINT_LED(a)		PORTC = (a & ~(3<<6)); PORTD = (((a>>6)&3)<<3);
//---------------------------------------------------------------------------------------------------------------------
// Macros
//---------------------------------------------------------------------------------------------------------------------
//---------------------------------------------------------------------------------------------------------------------
// Global variables
//---------------------------------------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------------------------------------
// Prototypes of global functions
//---------------------------------------------------------------------------------------------------------------------
//Write to RFM95W Registers
bool Rfm95WriteReg(uint8_t adress, uint8_t value);
//Read RFM95W Registers
bool Rfm95ReadReg(uint8_t adress, uint8_t *firstElementOfData);
//Initialize RFM95W and Switch to Standby Mode
bool Rfm95Init(float carFreq, uint8_t signalBw, uint8_t codRate, uint8_t spreadFactor, uint8_t crcOn, uint8_t preambleLen, uint8_t syncWord);
//Switch operating Mode of RFM95W
bool Rfm95ChangeMode(uint8_t mode);
//Transmit Data Packet via LoRa
bool Rfm95Tx(uint8_t *firstElementOfData, uint8_t numberOfElements);
//Receive Data Packet via Lora
bool Rfm95Rx(uint8_t *firstElementofData, uint8_t timeout, uint8_t *numberOfRxBytes);
bool Rfm95ChangeCarFreq(float carFreq);
bool Rfm95ChangeBandwidth (uint8_t bandwidth);
bool Rfm95ChangeSpreadFactor (uint8_t spreadFactor);
uint8_t Rfm95GetRandomNumber ();
#endif
