//=====================================================================================================================
/// @file		main.c
///
/// @brief		Main Program
///
/// @version	V1.0
///
/// @date		01.08.2020
///
/// @author		Philipp Holle
//=====================================================================================================================
//---------------------------------------------------------------------------------------------------------------------
// Includes
//---------------------------------------------------------------------------------------------------------------------
#include <stdint.h>
#include <stdlib.h>
#include <stdbool.h>
#include <avr/io.h>
#include "atmega328p.h"
#include "SPI_ATmega328p.h"
#include "RFM95W.h"
#include "ph_auxiliaries.h"
#include "lorawan.h"
#include "UART_atmega328p.h"

#include "STACKTEST.h"
//---------------------------------------------------------------------------------------------------------------------
// Macros
//---------------------------------------------------------------------------------------------------------------------
#define PRINT_LED(a)		PORTC = (a & ~(3<<6)); PORTD = (((a>>6)&3)<<3); //For Prototype Only

#define	CLOCKFREQ			16			//Frequency of Clocksource of MCU in MHz (post pre-scaler) // 1-16 MHz

#define CARRIER_FREQ		868100000	//Carrier Frequency in Hz				//862MHz to 1020MHz
#define BANDWIDTH			7			//Bandwidth of Chirp Spread Spectrum	//0=7.8kHz, 1=10.4kHz, 2=15.6kHz, 3=20.8kHz
																				//4=31.25kHz, 5=41.7kHz, 6=62.5kHz
																				//7=125kHz, 8=250kHz, 9=500kHz
#define CODING_RATE			1			//Error Coding Rate						//1=4/5, 2=4/6, 3=4/7, 4=4/8
#define SPREAD_FACTOR		7			//Spreading Factor (Chips/Symbol)		//7=128, 8=256, 9=512, 10=1024, 11=2048,
																				//12=4096
#define CRC_ON				1			//CRC									//0=disable, 1=enable
#define PREAMBLE_LEN		8			//Length of Preamble
#define SYNC_WORD			0x34		//Sync Word		
//#define RX_TIMEOUT						//Length of Rx Window in				//Symbol rate Rs = Bandwidth/(2^Spreading Factor)
										//Number of Symbols						//Symbol Period Ts = 1/Rs 											
							
//---------------------------------------------------------------------------------------------------------------------
// Global Variables
//---------------------------------------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------------------------------------
// Prototypes
//---------------------------------------------------------------------------------------------------------------------
//---------------------------------------------------------------------------------------------------------------------
// Functions
//---------------------------------------------------------------------------------------------------------------------

//=== Function: main ==================================================================================================
///
/// @brief	Main Program
///
/// @param	void
///
/// @return	void
//=====================================================================================================================
int main(void)
{
	//*************************************************************************
	// Variables
	//*************************************************************************
	uint8_t i;
	//*************************************************************************
	// Inits
	//*************************************************************************
	initStackTest();
	Atmega328pInit(CLOCKFREQ);
	SpiInitMaster();
	UartInit(CLOCKFREQ, 9600);
	Rfm95Init(CARRIER_FREQ, BANDWIDTH, CODING_RATE, SPREAD_FACTOR, CRC_ON, PREAMBLE_LEN, SYNC_WORD);
	
	//Set Port PC0-PC5 to Output
	DDRC |= (1<<DDC0) | (1<<DDC1) | (1<<DDC2) | (1<<DDC3) | (1<<DDC4) | (1<<DDC5);
	//Set PD3 & PD4 to Output
	DDRD |= (1<<DDD3) | (1<<DDD4);
	//*************************************************************************
	// While Loop
	//*************************************************************************
	while (1)
	{
		payloadPendingUpContent[0] = 0xAA;
		payloadPendingUpContent[1] = 0xBB;
		payloadPendingUpContent[2] = 0xCC;
		payloadPendingUp = true;
		payloadPendingUpLength = 3;
		
		devNonce[0] = 0x77;
		
		
		for (i=0;i<10;i++)
		{
			Atmega328pStopWatchStart(1000);
			while(!Atmega328pStopWatchCheck());
		}
		checkFreeStack();
		
		LorawanStartSession();
		
		while(1);
		
	}
	
	
	
}

